pub enum CargoInstallError {
CargoNotInstalled,
Io(Error),
AlreadyInstalled {
package: String,
stderr: String,
},
BinaryAlreadyExists {
binary: String,
stderr: String,
},
NoInstallableTargets {
stderr: String,
},
CompileFailed {
package: String,
stderr: String,
},
UnknownCargoError {
status: ExitStatus,
stderr: String,
},
}Expand description
Errors returned when executing cargo install.
Variants
CargoNotInstalled
The cargo executable could not be found in PATH.
Io(Error)
Spawning or waiting on the cargo process failed for an I/O reason.
AlreadyInstalled
Cargo reported that the package is already installed.
stderr contains the full original cargo output.
BinaryAlreadyExists
Cargo reported that a binary with the same name already exists.
stderr contains the full original cargo output.
NoInstallableTargets
Cargo reported that the selected package has no installable binaries or examples.
stderr contains the full original cargo output.
CompileFailed
Cargo failed while compiling the selected package.
stderr contains the full original cargo output.
UnknownCargoError
Cargo exited with a non-success status that this crate did not recognize.
stderr contains the full original cargo output.