pub struct CargoInstallBuilder { /* private fields */ }Expand description
Builder for CargoInstall.
Implementations
Sourceimpl CargoInstallBuilder
impl CargoInstallBuilder
Sourcepub fn root<VALUE: Into<PathBuf>>(self, value: VALUE) -> Self
pub fn root<VALUE: Into<PathBuf>>(self, value: VALUE) -> Self
Sets --root to override the installation root directory.
Sourcepub fn version<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn version<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --version to install a specific crate version requirement.
Sourcepub fn git<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn git<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --git to install from a git repository.
Sourcepub fn branch<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn branch<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --branch when installing from git.
Sourcepub fn tag<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn tag<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --tag when installing from git.
Sourcepub fn rev<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn rev<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --rev when installing from git.
Sourcepub fn target<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn target<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --target to build for a specific compilation target.
Sourcepub fn bin<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn bin<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --bin to install a specific binary target.
Sourcepub fn profile<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn profile<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets --profile to select the build profile used for installation.
Sourcepub fn path<VALUE: Into<PathBuf>>(self, value: VALUE) -> Self
pub fn path<VALUE: Into<PathBuf>>(self, value: VALUE) -> Self
Sets --path to install from a local crate directory.
Sourcepub fn crate_name<VALUE: Into<OsString>>(self, value: VALUE) -> Self
pub fn crate_name<VALUE: Into<OsString>>(self, value: VALUE) -> Self
Sets the registry crate name to install.
Sourcepub fn features<VALUE: Into<Vec<OsString>>>(self, value: VALUE) -> Self
pub fn features<VALUE: Into<Vec<OsString>>>(self, value: VALUE) -> Self
Sets --features using a feature list.
Sourcepub fn all_features<VALUE: Into<bool>>(self, value: VALUE) -> Self
pub fn all_features<VALUE: Into<bool>>(self, value: VALUE) -> Self
Enables --all-features.
Sourcepub fn no_default_features<VALUE: Into<bool>>(self, value: VALUE) -> Self
pub fn no_default_features<VALUE: Into<bool>>(self, value: VALUE) -> Self
Enables --no-default-features.
Sourcepub fn extra_args<VALUE: Into<Vec<OsString>>>(self, value: VALUE) -> Self
pub fn extra_args<VALUE: Into<Vec<OsString>>>(self, value: VALUE) -> Self
Appends additional arguments after all typed options.
Sourcepub fn stdout<VALUE: Into<Stdio>>(self, value: VALUE) -> Self
pub fn stdout<VALUE: Into<Stdio>>(self, value: VALUE) -> Self
Overrides the child process stdout configuration.
When not set, stdout inherits from the current process.
Sourcepub fn build(self) -> Result<CargoInstall, CargoInstallBuilderError>
pub fn build(self) -> Result<CargoInstall, CargoInstallBuilderError>